@@ -877,11 +877,6 @@ function Base.deleteat!(df::DataFrame, inds::AbstractVector)
         throw(ArgumentError("unsupported index $inds"))
     end
 
-    # workaround https://github.com/JuliaLang/julia/pull/41646
-    if VERSION <= v"1.6.2" && inds isa UnitRange{<:Integer}
-        inds = collect(inds)
-    end
-
     if !issorted(inds, lt=<=)
         throw(ArgumentError("Indices passed to deleteat! must be unique and sorted"))
     end
@@ -893,10 +888,6 @@ function Base.deleteat!(df::DataFrame, inds::AbstractVector{Bool})
     if length(inds) != size(df, 1)
         throw(BoundsError(df, (inds, :)))
     end
-    # workaround https://github.com/JuliaLang/julia/pull/41646
-    if VERSION <= v"1.6.2" && drop isa UnitRange{<:Integer}
-        inds = collect(inds)
-    end
     return _deleteat!_helper(df, inds)
 end
 
