@@ -22,13 +22,7 @@ using Test, DataFrames, OffsetArrays
     @test_throws ArgumentError insertcols!(df, :b => ov1)
     @test_throws DimensionMismatch df[!, :b] .= ov1
 
-    # this is consequence of the fact that OffsetArrays wrap AbstractRange in this case
-    # Base.CanonicalIndexError is not available in Julia 1.7 or earlier
-    if VERSION >= v"1.8-DEV"
-        @test_throws Base.CanonicalIndexError df[:, :a] = ov1
-    else
-        @test_throws ErrorException df[:, :a] = ov1
-    end
+    @test_throws Base.CanonicalIndexError df[:, :a] = ov1
 
     # this inconsistency is the consequence how setindex! for vector is defined in Base
     df = DataFrame(a=5:-1:1)
