@@ -1365,29 +1365,17 @@ end
     df = DataFrame(a=1:3)
     sdf = @view df[[3, 2], :]
     sdf.a .= 12.0
-    if isdefined(Base, :dotgetproperty) # Introduced in Julia 1.7
-        @test eltype(sdf.a) === Float64
-    else
-        @test eltype(sdf.a) === Int
-    end
+    @test eltype(sdf.a) === Float64
     @test df ≅ DataFrame(a=[1, 12, 12])
 
-    if VERSION >= v"1.7"
-        sdf.c .= 100
-        @test df ≅ DataFrame(a=[1, 12, 12], c=[missing, 100, 100])
-    else
-        @test_throws ArgumentError sdf.c .= 100
-    end
+    sdf.c .= 100
+    @test df ≅ DataFrame(a=[1, 12, 12], c=[missing, 100, 100])
 
     df = DataFrame(a=1:3)
     sdf = @view df[[3, 2], 1:1]
     @test_throws ArgumentError sdf.c = [5, 6]
     sdf.a .= 12.0
-    if isdefined(Base, :dotgetproperty) # Introduced in Julia 1.7
-        @test eltype(sdf.a) === Float64
-    else
-        @test eltype(sdf.a) === Int
-    end
+    @test eltype(sdf.a) === Float64
     @test df ≅ DataFrame(a=[1, 12, 12])
 end
 
